@@ -23,7 +23,7 @@ install("matplotlib")
 install("tweepy")
 install("nltk")
 install("textblob")
-import("fastdtw")
+install("fastdtw")
 ##----------------------------------------------IMPORTS---------------------------------------------------------------------------#	
 import json
 import ast
